summaryrefslogtreecommitdiff
path: root/gnu/xml/util/Resolver.java
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/xml/util/Resolver.java')
-rw-r--r--gnu/xml/util/Resolver.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/gnu/xml/util/Resolver.java b/gnu/xml/util/Resolver.java
index b16f9617f..e792d7d8e 100644
--- a/gnu/xml/util/Resolver.java
+++ b/gnu/xml/util/Resolver.java
@@ -1,5 +1,5 @@
/* Resolver.java --
- Copyright (C) 1999,2000,2001 Free Software Foundation, Inc.
+ Copyright (C) 1999,2000,2001, 2015 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -39,7 +39,7 @@ package gnu.xml.util;
import java.io.File;
import java.io.IOException;
-import java.util.Dictionary;
+import java.util.Map;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
@@ -65,7 +65,7 @@ public class Resolver implements EntityResolver, Cloneable
* @param directory File holding the specified files.
*/
public static void addDirectoryMapping (
- Dictionary table,
+ Map<String,String> table,
String mappings [][],
File directory
) throws IOException
@@ -164,18 +164,18 @@ public class Resolver implements EntityResolver, Cloneable
// note: cloneable, this is just copied; unguarded against mods
- private Dictionary pubidMapping;
+ private Map<String,String> pubidMapping;
/**
* Constructs a resolver which understands how to map PUBLIC identifiers
* to other URIs, typically for local copies of standard DTD components.
*
* @param dict maps PUBLIC identifiers to URIs. This is not
* copied; subsequent modifications will be reported through the
* resolution operations.
*/
- public Resolver (Dictionary dict)
- { pubidMapping = dict; }
+ public Resolver (Map<String,String> map)
+ { pubidMapping = map; }
// FIXME: want notion of a "system default" resolver, presumably
@@ -247,7 +247,7 @@ public class Resolver implements EntityResolver, Cloneable
String uri;
if (publicId != null
- && ((uri = (String) pubidMapping.get (publicId)) != null)) {
+ && ((uri = pubidMapping.get (publicId)) != null)) {
retval = new InputSource (uri);
retval.setPublicId (publicId);
}
@@ -164,18 +164,18 @@ public class Resolver implements EntityResolver, Cloneable
* to other URIs, typically for local copies of standard DTD components.
*
- * @param dict maps PUBLIC identifiers to URIs. This is not
+ * @param map maps PUBLIC identifiers to URIs. This is not
* copied; subsequent modifications will be reported through the
* resolution operations.